pm4py.algo.discovery.inductive.variants.im\_f package
=====================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.inductive.variants.im_f.data_structures

Submodules
----------

pm4py.algo.discovery.inductive.variants.im\_f.algorithm module
--------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.inductive.variants.im_f.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.inductive.variants.im\_f.fall\_through\_infrequent module
------------------------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.inductive.variants.im_f.fall_through_infrequent
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.inductive.variants.im\_f.splitting\_infrequent module
--------------------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.inductive.variants.im_f.splitting_infrequent
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.inductive.variants.im_f
   :members:
   :undoc-members:
   :show-inheritance:
